InlinePtxOp

Struct InlinePtxOp 

pub struct InlinePtxOp { /* private fields */ }
Inline PTX. Restricted to zero or one results because C++ semantics are too hard otherwise. Note that this does not directly map to PTX, because it actually destructures vectors to PTX vector expressions automatically. This means more than one register can be returned if it’s part of a vector expression. To denote the difference, the syntax uses $0, $1 etc for Pliron values, as opposed to the usual %0, %1 etc for the PTX registers.

Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
cuda_inline_ptx_ptxATTR_KEY_CUDA_INLINE_PTX_PTXStringAttr
cuda_inline_ptx_volatileATTR_KEY_CUDA_INLINE_PTX_VOLATILEUnitAttr
cuda_inline_ptx_clobbersATTR_KEY_CUDA_INLINE_PTX_CLOBBERSVecAttr
cuda_inline_ptx_memory_clobbersATTR_KEY_CUDA_INLINE_PTX_MEMORY_CLOBBERSMemoryClobbersAttr
cuda_inline_ptx_in_specATTR_KEY_CUDA_INLINE_PTX_IN_SPECInputSpecsAttr

Implementations

Source

impl InlinePtxOp

pub fn get_attr_cuda_inline_ptx_ptx<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>

Get a Ref to the value of the attribute named cuda_inline_ptx_ptx. The Ref is a borrow of the containing Operation object.

pub fn set_attr_cuda_inline_ptx_ptx(&self, ctx: &Context, value: StringAttr)

Set the value of the attribute named cuda_inline_ptx_ptx.

pub fn get_attr_cuda_inline_ptx_volatile<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, UnitAttr>>

Get a Ref to the value of the attribute named cuda_inline_ptx_volatile. The Ref is a borrow of the containing Operation object.

pub fn set_attr_cuda_inline_ptx_volatile(&self, ctx: &Context, value: UnitAttr)

Set the value of the attribute named cuda_inline_ptx_volatile.

pub fn get_attr_cuda_inline_ptx_clobbers<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, VecAttr>>

Get a Ref to the value of the attribute named cuda_inline_ptx_clobbers. The Ref is a borrow of the containing Operation object.

pub fn set_attr_cuda_inline_ptx_clobbers(&self, ctx: &Context, value: VecAttr)

Set the value of the attribute named cuda_inline_ptx_clobbers.

pub fn get_attr_cuda_inline_ptx_memory_clobbers<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, MemoryClobbersAttr>>

Get a Ref to the value of the attribute named cuda_inline_ptx_memory_clobbers. The Ref is a borrow of the containing Operation object.

pub fn set_attr_cuda_inline_ptx_memory_clobbers( &self, ctx: &Context, value: MemoryClobbersAttr, )

Set the value of the attribute named cuda_inline_ptx_memory_clobbers.

pub fn get_attr_cuda_inline_ptx_in_spec<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, InputSpecsAttr>>

Get a Ref to the value of the attribute named cuda_inline_ptx_in_spec. The Ref is a borrow of the containing Operation object.

pub fn set_attr_cuda_inline_ptx_in_spec( &self, ctx: &Context, value: InputSpecsAttr, )

Set the value of the attribute named cuda_inline_ptx_in_spec.

Source

impl InlinePtxOp

pub fn new( ctx: &mut Context, result_ty: Option<TypeHandle>, ptx: impl Display, inputs: Vec<Value>, ) -> Self

pub fn new_volatile( ctx: &mut Context, result_ty: Option<TypeHandle>, ptx: impl Display, inputs: Vec<Value>, ) -> Self

pub fn set_clobbers(&self, ctx: &Context, clobbers: Vec<String>)

pub fn clobbers(&self, ctx: &Context) -> Vec<String>

pub fn raw_ptx<'a>(&self, ctx: &'a Context) -> Ref<'a, str>

pub fn is_volatile(&self, ctx: &Context) -> bool

pub fn inputs(&self, ctx: &Context) -> Vec<Value>

pub fn result(&self, ctx: &Context) -> Option<Value>