pub struct ReadDim3BuiltinOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
msl_read_dim3_builtin_dim | ATTR_KEY_MSL_READ_DIM3_BUILTIN_DIM | IndexAttr |
Implementations
Sourceimpl ReadDim3BuiltinOp
impl ReadDim3BuiltinOp
Sourcepub fn get_attr_msl_read_dim3_builtin_dim<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_msl_read_dim3_builtin_dim<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named msl_read_dim3_builtin_dim.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_msl_read_dim3_builtin_dim(
&self,
ctx: &Context,
value: IndexAttr,
)
pub fn set_attr_msl_read_dim3_builtin_dim( &self, ctx: &Context, value: IndexAttr, )
Set the value of the attribute named msl_read_dim3_builtin_dim.
Sourceimpl ReadDim3BuiltinOp
impl ReadDim3BuiltinOp
pub fn new( ctx: &mut Context, result_ty: TypeHandle, builtin: Value, dim: impl Into<IndexAttr>, ) -> Self
pub fn builtin(&self, ctx: &Context) -> Value
pub fn builtin_as_use(&self, ctx: &Context) -> Use<Value>
pub fn dim<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn set_dim(&self, ctx: &Context, value: impl Into<IndexAttr>)