Module shared

Module shared 

Modules

binary
unary
wmma_api_base

Structs

BinaryInstruction
Body
A body is composed of a list of instructions.
CompilationOptions
ComputeKernel
CppCompiler
CppSupportedFeatures
CubeIndexFlags
Cube indexes flags. When true the corresponding index is declared and computed as needed in the kernel.
Flags
Flags gathered during Cube IR translation for the kernel compilation.
FragmentType
IndexInstruction
IndexedValue
KernelArg
ManualMma
MmaShape
OptimizedArgs
SharedMemory
UnaryInstruction

Enums

Builtin
Elem
FP4Kind
FP6Kind
FP8Kind
FragmentIdent
FragmentLayout
Instruction
Item
PointerClass
Value
WarpInstruction
WmmaInstruction
Warp Matrix-Multiply and Accumulate Instruction.

Traits

Architecture
Component
Dialect
DialectBindings
DialectCubeBuiltins
DialectIncludes
DialectInstructions
DialectProcessors
IR Processors to be applied to the scopes during processing. CheckedIO is always applied by default, so these are only for target specific processors like MMA index processors.
DialectTypes
DialectWarpReduceCompiler
DialectWmmaCompiler
FmtLeft

Functions

compile_bindings
compile_info_dynamic
compile_info_static
define_array_polyfill
Define a minimal version of C++’s std::array so we can match Rust semantics on arrays.
frag_as_ptr
frag_ident_str
frag_layout_str
register_mma_features
register_scaled_mma_features
register_supported_types
register_wmma_features
type_definitions
type_info_definition_sized
type_vectorized_definitions
value_to_frag

Type Aliases

MslComputeKernel
SupportedMmaCombinations
SupportedScaledMmaCombinations