pub struct CppReadScalarOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cpp_read_scalar_id | ATTR_KEY_CPP_READ_SCALAR_ID | IndexAttr |
cpp_read_scalar_ty | ATTR_KEY_CPP_READ_SCALAR_TY | TypeAttr |
Implementations
Sourceimpl CppReadScalarOp
impl CppReadScalarOp
Sourcepub fn get_attr_cpp_read_scalar_id<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_cpp_read_scalar_id<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named cpp_read_scalar_id.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cpp_read_scalar_id(&self, ctx: &Context, value: IndexAttr)
pub fn set_attr_cpp_read_scalar_id(&self, ctx: &Context, value: IndexAttr)
Set the value of the attribute named cpp_read_scalar_id.
Sourcepub fn get_attr_cpp_read_scalar_ty<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_cpp_read_scalar_ty<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named cpp_read_scalar_ty.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cpp_read_scalar_ty(&self, ctx: &Context, value: TypeAttr)
pub fn set_attr_cpp_read_scalar_ty(&self, ctx: &Context, value: TypeAttr)
Set the value of the attribute named cpp_read_scalar_ty.
Sourceimpl CppReadScalarOp
impl CppReadScalarOp
pub fn new( ctx: &mut Context, base: Value, id: impl Into<IndexAttr>, ty: impl Into<TypeAttr>, ) -> Self
pub fn base(&self, ctx: &Context) -> Value
pub fn base_as_use(&self, ctx: &Context) -> Use<Value>
pub fn id<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn ty<'a>(&self, ctx: &'a Context) -> Ref<'a, TypeAttr>
pub fn set_id(&self, ctx: &Context, value: impl Into<IndexAttr>)
pub fn set_ty(&self, ctx: &Context, value: impl Into<TypeAttr>)