pub struct CppReadStaticMetaOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cpp_read_static_meta_offset | ATTR_KEY_CPP_READ_STATIC_META_OFFSET | IndexAttr |
Implementations
Sourceimpl CppReadStaticMetaOp
impl CppReadStaticMetaOp
Sourcepub fn get_attr_cpp_read_static_meta_offset<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_cpp_read_static_meta_offset<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named cpp_read_static_meta_offset.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cpp_read_static_meta_offset(
&self,
ctx: &Context,
value: IndexAttr,
)
pub fn set_attr_cpp_read_static_meta_offset( &self, ctx: &Context, value: IndexAttr, )
Set the value of the attribute named cpp_read_static_meta_offset.
Sourceimpl CppReadStaticMetaOp
impl CppReadStaticMetaOp
pub fn new(ctx: &mut Context, base: Value, offset: impl Into<IndexAttr>) -> Self
pub fn base(&self, ctx: &Context) -> Value
pub fn base_as_use(&self, ctx: &Context) -> Use<Value>
pub fn offset<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn set_offset(&self, ctx: &Context, value: impl Into<IndexAttr>)