pub struct DeclareLocalOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cpp_declare_local_value_ty | ATTR_KEY_CPP_DECLARE_LOCAL_VALUE_TY | TypeAttr |
cpp_declare_local_initializer | ATTR_KEY_CPP_DECLARE_LOCAL_INITIALIZER | Any |
Implementations
Sourceimpl DeclareLocalOp
impl DeclareLocalOp
Sourcepub fn get_attr_cpp_declare_local_value_ty<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_cpp_declare_local_value_ty<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named cpp_declare_local_value_ty.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cpp_declare_local_value_ty(
&self,
ctx: &Context,
value: TypeAttr,
)
pub fn set_attr_cpp_declare_local_value_ty( &self, ctx: &Context, value: TypeAttr, )
Set the value of the attribute named cpp_declare_local_value_ty.
Sourcepub fn get_attr_cpp_declare_local_initializer<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AttrObj>>
pub fn get_attr_cpp_declare_local_initializer<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AttrObj>>
Get a Ref to the value of the attribute named cpp_declare_local_initializer.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cpp_declare_local_initializer(
&self,
ctx: &Context,
value: AttrObj,
)
pub fn set_attr_cpp_declare_local_initializer( &self, ctx: &Context, value: AttrObj, )
Set the value of the attribute named cpp_declare_local_initializer.
Sourceimpl DeclareLocalOp
impl DeclareLocalOp
pub fn new( ctx: &mut Context, value_ty: impl Into<TypeAttr>, initializer: Option<AttrObj>, ) -> Self
pub fn value_ty<'a>(&self, ctx: &'a Context) -> Ref<'a, TypeAttr>
pub fn initializer<'a>(&self, ctx: &'a Context) -> Option<Ref<'a, AttrObj>>
pub fn set_value_ty(&self, ctx: &Context, value: impl Into<TypeAttr>)
pub fn set_initializer(&self, ctx: &Context, value: impl Into<AttrObj>)
pub fn remove_initializer(&self, ctx: &Context)