pub struct DeclareMatrixOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cpp_declare_matrix_value_ty | ATTR_KEY_CPP_DECLARE_MATRIX_VALUE_TY | TypeAttr |
Implementations
Sourceimpl DeclareMatrixOp
impl DeclareMatrixOp
Sourcepub fn get_attr_cpp_declare_matrix_value_ty<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_cpp_declare_matrix_value_ty<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named cpp_declare_matrix_value_ty.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cpp_declare_matrix_value_ty(
&self,
ctx: &Context,
value: TypeAttr,
)
pub fn set_attr_cpp_declare_matrix_value_ty( &self, ctx: &Context, value: TypeAttr, )
Set the value of the attribute named cpp_declare_matrix_value_ty.