pub trait DialectProcessors<D: Dialect> {
// Required method
fn processors() -> Vec<Box<dyn Processor>>;
}Expand description
IR Processors to be applied to the scopes during processing. CheckedIO is always applied
by default, so these are only for target specific processors like MMA index processors.
Required Methods
fn processors() -> Vec<Box<dyn Processor>>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.