Module ty

Module ty 

Structs

InfoStructType
UniformPointerType
Uvec3Type
Vector of three unsigned integers. This is the only native vector type that’s actually relevant for codegen, so we can just special case it and only use it where necessary (builtin types).

Traits

TypeExt
TypeExtCPP
TypeToCPP
TypedExtCPP

Functions

ptr_constness