Uvec3Type

Struct Uvec3Type 

pub struct Uvec3Type;
Vector of three unsigned integers. This is the only native vector type that’s actually relevant for codegen, so we can just special case it and only use it where necessary (builtin types).

Implementations

Source

impl Uvec3Type

pub fn get(ctx: &Context) -> TypedHandle<Self>

Get or create a new instance.