pub struct Cuda;Trait Implementations
impl Copy for Cuda
Sourceimpl LowerOp<Cuda> for SaturatingSAddOp
impl LowerOp<Cuda> for SaturatingSAddOp
Sourceimpl LowerOp<Cuda> for SaturatingSSubOp
impl LowerOp<Cuda> for SaturatingSSubOp
Sourceimpl LowerOp<Cuda> for CastOp
special cast function for recursive conversion in the case of minifloat to minifloat conversion
impl LowerOp<Cuda> for CastOp
special cast function for recursive conversion in the case of minifloat to minifloat conversion
Needs to jump through a lot of hoops to deal with CUDA nonsense. The overview of available conversions is as follows:
| From | To | Extra args |
|---|---|---|
| f16/bf16/f32/f64 | e4m3/e5m2 | Interpretation, saturation |
| f16/bf16/f32/f64 | e3m2/e2m3/e2m1 | Interpretation, rounding |
| bf16/f32/f64 | e8m0 | saturation, rounding |
| e4m3/e5m2/e3m2/e2m3/e2m1 | f16 | Interpretation, |
| e8m0 | bf16 |
When the input and output don’t match these options, we need to do a two-step conversion.
When the input is a minifloat we always need to cast out to f16/bf16, and then convert to
the actual out type if it differs. Trying to cast ints also requires an extra conversion, and
so does f16 to e8m0 (though it’s not recommended to do that anyways, you should be using
e5m2 for that since you don’t have 8 bits of exponent in f16).
See also: https://docs.nvidia.com/cuda/cuda-math-api/cuda_math_api/group__CUDA__MATH__FP8__MISC.html https://docs.nvidia.com/cuda/cuda-math-api/cuda_math_api/group__CUDA__MATH__FP6__MISC.html https://docs.nvidia.com/cuda/cuda-math-api/cuda_math_api/group__CUDA__MATH__FP4__MISC.html
Sourceimpl LowerOp<Cuda> for RowIndexOp
impl LowerOp<Cuda> for RowIndexOp
Sourceimpl LowerOp<Cuda> for ColIndexOp
impl LowerOp<Cuda> for ColIndexOp
Sourceimpl LowerOp<Cuda> for InlineAsmOp
impl LowerOp<Cuda> for InlineAsmOp
Sourceimpl LowerOp<Cuda> for MmaManualOp
impl LowerOp<Cuda> for MmaManualOp
Sourceimpl LowerOp<Cuda> for MmaManualScaledOp
impl LowerOp<Cuda> for MmaManualScaledOp
Sourceimpl LowerOp<Cuda> for LdMatrixOp
impl LowerOp<Cuda> for LdMatrixOp
Sourceimpl LowerOp<Cuda> for StMatrixOp
impl LowerOp<Cuda> for StMatrixOp
Sourceimpl LowerOp<Cuda> for CopyAsyncOp
impl LowerOp<Cuda> for CopyAsyncOp
Sourceimpl LowerOp<Cuda> for CommitCopyAsyncOp
impl LowerOp<Cuda> for CommitCopyAsyncOp
Sourceimpl LowerOp<Cuda> for TmaLoadIm2colOp
impl LowerOp<Cuda> for TmaLoadIm2colOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicIAddOp
impl LowerOpAfterUnroll<Cuda> for AtomicIAddOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicFAddOp
impl LowerOpAfterUnroll<Cuda> for AtomicFAddOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicSMinOp
impl LowerOpAfterUnroll<Cuda> for AtomicSMinOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicUMinOp
impl LowerOpAfterUnroll<Cuda> for AtomicUMinOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicFMinOp
impl LowerOpAfterUnroll<Cuda> for AtomicFMinOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicSMaxOp
impl LowerOpAfterUnroll<Cuda> for AtomicSMaxOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicUMaxOp
impl LowerOpAfterUnroll<Cuda> for AtomicUMaxOp
Sourceimpl LowerOpAfterUnroll<Cuda> for AtomicFMaxOp
impl LowerOpAfterUnroll<Cuda> for AtomicFMaxOp
Sourceimpl OpToCPP<Cuda> for MemCopyAsyncOp
impl OpToCPP<Cuda> for MemCopyAsyncOp
Sourceimpl OpToCPP<Cuda> for MemCopyAsyncTxOp
impl OpToCPP<Cuda> for MemCopyAsyncTxOp
Sourceimpl OpToCPP<Cuda> for ArriveAndExpectTxOp
impl OpToCPP<Cuda> for ArriveAndExpectTxOp
Sourceimpl OpToCPP<Cuda> for ExpectTxOp
impl OpToCPP<Cuda> for ExpectTxOp
Sourceimpl OpToCPP<Cuda> for WaitParityOp
impl OpToCPP<Cuda> for WaitParityOp
Sourceimpl OpToCPP<Cuda> for ArriveAndWaitOp
impl OpToCPP<Cuda> for ArriveAndWaitOp
Sourceimpl OpToCPP<Cuda> for ReadBuiltinOp
impl OpToCPP<Cuda> for ReadBuiltinOp
Sourceimpl OpToCPP<Cuda> for SyncAsyncProxyOp
impl OpToCPP<Cuda> for SyncAsyncProxyOp
Sourceimpl OpToCPP<Cuda> for DeclareMatrixOp
impl OpToCPP<Cuda> for DeclareMatrixOp
Sourceimpl OpToCPP<Cuda> for MultiplyAccumulateOp
impl OpToCPP<Cuda> for MultiplyAccumulateOp
Sourceimpl OpToCPP<Cuda> for BroadcastOp
impl OpToCPP<Cuda> for BroadcastOp
Sourceimpl OpToCPP<Cuda> for ShuffleXorOp
impl OpToCPP<Cuda> for ShuffleXorOp
Sourceimpl OpToCPP<Cuda> for ShuffleUpOp
impl OpToCPP<Cuda> for ShuffleUpOp
Sourceimpl OpToCPP<Cuda> for ShuffleDownOp
impl OpToCPP<Cuda> for ShuffleDownOp
Sourceimpl OpToCPP<Cuda> for InlinePtxOp
impl OpToCPP<Cuda> for InlinePtxOp
Sourceimpl OpToCPP<Cuda> for BarrierNativeHandleOp
impl OpToCPP<Cuda> for BarrierNativeHandleOp
Sourceimpl OpToCPP<Cuda> for TensorMapAddrOp
impl OpToCPP<Cuda> for TensorMapAddrOp
Sourceimpl OpToCPP<Cuda> for TmaStoreOp
impl OpToCPP<Cuda> for TmaStoreOp
Sourceimpl OpToCPP<Cuda> for CommitGroupOp
impl OpToCPP<Cuda> for CommitGroupOp
Sourceimpl OpToCPP<Cuda> for WaitGroupOp
impl OpToCPP<Cuda> for WaitGroupOp
Sourceimpl OpToCPP<Cuda> for WaitGroupReadOp
impl OpToCPP<Cuda> for WaitGroupReadOp
Sourceimpl RequiresIncludesOp<Cuda> for ReadBuiltinOp
impl RequiresIncludesOp<Cuda> for ReadBuiltinOp
Sourceimpl RequiresIncludesOp<Cuda> for SyncAsyncProxyOp
impl RequiresIncludesOp<Cuda> for SyncAsyncProxyOp
Sourceimpl RequiresIncludesOp<Cuda> for TmaStoreOp
impl RequiresIncludesOp<Cuda> for TmaStoreOp
Sourceimpl RequiresIncludesOp<Cuda> for CommitGroupOp
impl RequiresIncludesOp<Cuda> for CommitGroupOp
Sourceimpl RequiresIncludesOp<Cuda> for WaitGroupOp
impl RequiresIncludesOp<Cuda> for WaitGroupOp
Sourceimpl RequiresIncludesOp<Cuda> for WaitGroupReadOp
impl RequiresIncludesOp<Cuda> for WaitGroupReadOp
Sourceimpl RequiresIncludesType<Cuda> for PointerType
impl RequiresIncludesType<Cuda> for PointerType
Sourceimpl RequiresIncludesType<Cuda> for ArrayType
impl RequiresIncludesType<Cuda> for ArrayType
Sourceimpl RequiresIncludesType<Cuda> for RuntimeArrayType
impl RequiresIncludesType<Cuda> for RuntimeArrayType
Sourceimpl RequiresIncludesType<Cuda> for VectorType
impl RequiresIncludesType<Cuda> for VectorType
Sourceimpl RequiresIncludesType<Cuda> for BarrierType
impl RequiresIncludesType<Cuda> for BarrierType
Sourceimpl RequiresIncludesType<Cuda> for Complex32Type
impl RequiresIncludesType<Cuda> for Complex32Type
Sourceimpl RequiresIncludesType<Cuda> for Complex64Type
impl RequiresIncludesType<Cuda> for Complex64Type
Sourceimpl RequiresIncludesType<Cuda> for MatrixType
impl RequiresIncludesType<Cuda> for MatrixType
Sourceimpl RequiresIncludesType<Cuda> for TFloat32Type
impl RequiresIncludesType<Cuda> for TFloat32Type
Sourceimpl RequiresIncludesType<Cuda> for Float16Type
impl RequiresIncludesType<Cuda> for Float16Type
Sourceimpl RequiresIncludesType<Cuda> for Float16x2Type
impl RequiresIncludesType<Cuda> for Float16x2Type
Sourceimpl RequiresIncludesType<Cuda> for BFloat16Type
impl RequiresIncludesType<Cuda> for BFloat16Type
Sourceimpl RequiresIncludesType<Cuda> for BFloat16x2Type
impl RequiresIncludesType<Cuda> for BFloat16x2Type
Sourceimpl RequiresIncludesType<Cuda> for Float8E4M3Type
impl RequiresIncludesType<Cuda> for Float8E4M3Type
Sourceimpl RequiresIncludesType<Cuda> for Float8E5M2Type
impl RequiresIncludesType<Cuda> for Float8E5M2Type
Sourceimpl RequiresIncludesType<Cuda> for Float8E8M0Type
impl RequiresIncludesType<Cuda> for Float8E8M0Type
Sourceimpl RequiresIncludesType<Cuda> for Float8E4M3x2Type
impl RequiresIncludesType<Cuda> for Float8E4M3x2Type
Sourceimpl RequiresIncludesType<Cuda> for Float8E5M2x2Type
impl RequiresIncludesType<Cuda> for Float8E5M2x2Type
Sourceimpl RequiresIncludesType<Cuda> for Float8E8M0x2Type
impl RequiresIncludesType<Cuda> for Float8E8M0x2Type
Sourceimpl RequiresIncludesType<Cuda> for Float6E3M2Type
impl RequiresIncludesType<Cuda> for Float6E3M2Type
Sourceimpl RequiresIncludesType<Cuda> for Float6E2M3Type
impl RequiresIncludesType<Cuda> for Float6E2M3Type
Sourceimpl RequiresIncludesType<Cuda> for Float6E3M2x2Type
impl RequiresIncludesType<Cuda> for Float6E3M2x2Type
Sourceimpl RequiresIncludesType<Cuda> for Float6E2M3x2Type
impl RequiresIncludesType<Cuda> for Float6E2M3x2Type
Sourceimpl RequiresIncludesType<Cuda> for Float4E2M1Type
impl RequiresIncludesType<Cuda> for Float4E2M1Type
Sourceimpl RequiresIncludesType<Cuda> for Float4E2M1x2Type
impl RequiresIncludesType<Cuda> for Float4E2M1x2Type
Sourceimpl TypeToCPP<Cuda> for MatrixType
impl TypeToCPP<Cuda> for MatrixType
Sourceimpl TypeToCPP<Cuda> for TensorMapType
impl TypeToCPP<Cuda> for TensorMapType
Sourceimpl TypeToCPP<Cuda> for BarrierType
impl TypeToCPP<Cuda> for BarrierType
Sourceimpl TypeToCPP<Cuda> for BarrierTokenType
impl TypeToCPP<Cuda> for BarrierTokenType
Sourceimpl TypeToCPP<Cuda> for PointerType
impl TypeToCPP<Cuda> for PointerType
Sourceimpl TypeToCPP<Cuda> for UniformPointerType
impl TypeToCPP<Cuda> for UniformPointerType
Sourceimpl TypeToCPP<Cuda> for Complex32Type
impl TypeToCPP<Cuda> for Complex32Type
Sourceimpl TypeToCPP<Cuda> for Complex64Type
impl TypeToCPP<Cuda> for Complex64Type
Sourceimpl TypeToCPP<Cuda> for TFloat32Type
impl TypeToCPP<Cuda> for TFloat32Type
Sourceimpl TypeToCPP<Cuda> for Float16x2Type
impl TypeToCPP<Cuda> for Float16x2Type
Sourceimpl TypeToCPP<Cuda> for BFloat16x2Type
impl TypeToCPP<Cuda> for BFloat16x2Type
Sourceimpl TypeToCPP<Cuda> for Float8E4M3x2Type
impl TypeToCPP<Cuda> for Float8E4M3x2Type
Sourceimpl TypeToCPP<Cuda> for Float8E5M2x2Type
impl TypeToCPP<Cuda> for Float8E5M2x2Type
Sourceimpl TypeToCPP<Cuda> for Float8E8M0x2Type
impl TypeToCPP<Cuda> for Float8E8M0x2Type
Sourceimpl TypeToCPP<Cuda> for Float6E3M2x2Type
impl TypeToCPP<Cuda> for Float6E3M2x2Type
Sourceimpl TypeToCPP<Cuda> for Float6E2M3x2Type
impl TypeToCPP<Cuda> for Float6E2M3x2Type
Sourceimpl TypeToCPP<Cuda> for Float4E2M1x2Type
impl TypeToCPP<Cuda> for Float4E2M1x2Type
Sourceimpl TypeToCPP<Cuda> for Float16Type
impl TypeToCPP<Cuda> for Float16Type
Sourceimpl TypeToCPP<Cuda> for BFloat16Type
impl TypeToCPP<Cuda> for BFloat16Type
Sourceimpl TypeToCPP<Cuda> for Float8E4M3Type
impl TypeToCPP<Cuda> for Float8E4M3Type
Sourceimpl TypeToCPP<Cuda> for Float8E5M2Type
impl TypeToCPP<Cuda> for Float8E5M2Type
Sourceimpl TypeToCPP<Cuda> for Float8E8M0Type
impl TypeToCPP<Cuda> for Float8E8M0Type
Sourceimpl TypeToCPP<Cuda> for Float6E3M2Type
impl TypeToCPP<Cuda> for Float6E3M2Type
Sourceimpl TypeToCPP<Cuda> for Float6E2M3Type
impl TypeToCPP<Cuda> for Float6E2M3Type