Re-exports
pub use mma::manual::supported_mma_combinations;pub use mma::manual::supported_scaled_mma_combinations;
Modules
- arch
- atomic
- CUDA’s C++ atomic APIs are a mess of inconsistency. Old-style APIs use weird types, newer
std::atomicAPIs don’t support many types. So for ops where type support is complex, we lower the atomics directly to PTX. This allows a consistent API across all the different type and vectorization options, and significantly extends the interface that can be accessed from C++. - barrier
- binary
- builtin
- convert
- Cuda conversion functions
- dialect
- mma
- packed_
ops - plane
- ptx
- signature
- tma
- ty