pub struct GenericToSharedOp { /* private fields */ }Expand description
Equivalent of __cvta_generic_to_shared, required when a PTX instruction uses a specific
.shared modifier. It should only be used to cast a pointer for use in that specific context,
and using it without adding the .shared modifier will break. Using shared addresses in generic
instructions will also break, which is why this isn’t automatically applied in InlinePtxOp.
Implementations