pub struct InlinePtxOp { /* private fields */ }Expand description
Inline PTX. Restricted to zero or one results because C++ semantics are too hard otherwise.
Note that this does not directly map to PTX, because it actually destructures vectors to PTX
vector expressions automatically. This means more than one register can be returned if it’s part
of a vector expression. To denote the difference, the syntax uses $0, $1 etc for Pliron
values, as opposed to the usual %0, %1 etc for the PTX registers.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cuda_inline_ptx_ptx | ATTR_KEY_CUDA_INLINE_PTX_PTX | StringAttr |
cuda_inline_ptx_volatile | ATTR_KEY_CUDA_INLINE_PTX_VOLATILE | UnitAttr |
cuda_inline_ptx_clobbers | ATTR_KEY_CUDA_INLINE_PTX_CLOBBERS | VecAttr |
cuda_inline_ptx_memory_clobbers | ATTR_KEY_CUDA_INLINE_PTX_MEMORY_CLOBBERS | MemoryClobbersAttr |
cuda_inline_ptx_in_spec | ATTR_KEY_CUDA_INLINE_PTX_IN_SPEC | InputSpecsAttr |
Implementations
Sourceimpl InlinePtxOp
impl InlinePtxOp
Sourcepub fn get_attr_cuda_inline_ptx_ptx<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_cuda_inline_ptx_ptx<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named cuda_inline_ptx_ptx.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cuda_inline_ptx_ptx(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_cuda_inline_ptx_ptx(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named cuda_inline_ptx_ptx.
Sourcepub fn get_attr_cuda_inline_ptx_volatile<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, UnitAttr>>
pub fn get_attr_cuda_inline_ptx_volatile<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, UnitAttr>>
Get a Ref to the value of the attribute named cuda_inline_ptx_volatile.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cuda_inline_ptx_volatile(&self, ctx: &Context, value: UnitAttr)
pub fn set_attr_cuda_inline_ptx_volatile(&self, ctx: &Context, value: UnitAttr)
Set the value of the attribute named cuda_inline_ptx_volatile.
Sourcepub fn get_attr_cuda_inline_ptx_clobbers<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, VecAttr>>
pub fn get_attr_cuda_inline_ptx_clobbers<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, VecAttr>>
Get a Ref to the value of the attribute named cuda_inline_ptx_clobbers.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cuda_inline_ptx_clobbers(&self, ctx: &Context, value: VecAttr)
pub fn set_attr_cuda_inline_ptx_clobbers(&self, ctx: &Context, value: VecAttr)
Set the value of the attribute named cuda_inline_ptx_clobbers.
Sourcepub fn get_attr_cuda_inline_ptx_memory_clobbers<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, MemoryClobbersAttr>>
pub fn get_attr_cuda_inline_ptx_memory_clobbers<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, MemoryClobbersAttr>>
Get a Ref to the value of the attribute named cuda_inline_ptx_memory_clobbers.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cuda_inline_ptx_memory_clobbers(
&self,
ctx: &Context,
value: MemoryClobbersAttr,
)
pub fn set_attr_cuda_inline_ptx_memory_clobbers( &self, ctx: &Context, value: MemoryClobbersAttr, )
Set the value of the attribute named cuda_inline_ptx_memory_clobbers.
Sourcepub fn get_attr_cuda_inline_ptx_in_spec<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, InputSpecsAttr>>
pub fn get_attr_cuda_inline_ptx_in_spec<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, InputSpecsAttr>>
Get a Ref to the value of the attribute named cuda_inline_ptx_in_spec.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cuda_inline_ptx_in_spec(
&self,
ctx: &Context,
value: InputSpecsAttr,
)
pub fn set_attr_cuda_inline_ptx_in_spec( &self, ctx: &Context, value: InputSpecsAttr, )
Set the value of the attribute named cuda_inline_ptx_in_spec.
Sourceimpl InlinePtxOp
impl InlinePtxOp
pub fn new( ctx: &mut Context, result_ty: Option<TypeHandle>, ptx: impl Display, inputs: Vec<Value>, ) -> Self
pub fn new_volatile( ctx: &mut Context, result_ty: Option<TypeHandle>, ptx: impl Display, inputs: Vec<Value>, ) -> Self
pub fn set_clobbers(&self, ctx: &Context, clobbers: Vec<String>)
pub fn clobbers(&self, ctx: &Context) -> Vec<String>
pub fn raw_ptx<'a>(&self, ctx: &'a Context) -> Ref<'a, str>
pub fn is_volatile(&self, ctx: &Context) -> bool
pub fn inputs(&self, ctx: &Context) -> Vec<Value>
pub fn result(&self, ctx: &Context) -> Option<Value>