pub struct TensorMapAddrOp { /* private fields */ }Expand description
Tensor maps are weird because they’re passed as a reference but consumed by pointer. Don’t want
to add a generic ReferenceOp, so for now just do a tensor-map specific reference. That way
it doesn’t need to deal with Metal address space nonsense. Returns the raw address as u64
since it’s always used for PTX anyways, and that coerces pointers to u64.
Implementations