pub struct Uvec3Type;Expand description
Vector of three unsigned integers. This is the only native vector type that’s actually relevant for codegen, so we can just special case it and only use it where necessary (builtin types).
Implementations